diff --git a/hive/server/database_api/methods.py b/hive/server/database_api/methods.py
index c617bcfe038905eadcfe8a2101ee11dc629464c0..ec8daeb3821eaf26ce495c4fa7d5cbd0257dfedc 100644
--- a/hive/server/database_api/methods.py
+++ b/hive/server/database_api/methods.py
@@ -213,7 +213,7 @@ async def find_votes(context, params: dict, votes_presentation = VotesPresentati
             num_changes,
             reputation
         FROM
-            wv_hive_votes_accounts_permlinks
+            hive_votes_accounts_permlinks_view
         WHERE
             author = :author AND permlink = :permlink
         ORDER BY id
diff --git a/hive/db/schema.py b/hive/db/schema.py
index 31debd1e3ff13bcbe3db0f1d676ea09244b0e2f7..9749db39bb98c82720a8fbc69982620567125eb9 100644
--- a/hive/db/schema.py
+++ b/hive/db/schema.py
@@ -696,9 +696,9 @@ def setup(db):
     db.query_no_return(sql)
 
     sql = """
         DROP VIEW IF EXISTS wv_hive_votes_accounts_permlinks
         ;
-        CREATE VIEW wv_hive_votes_accounts_permlinks
+        CREATE VIEW hive_votes_accounts_permlinks_view
         AS
         SELECT
             ha_v.id as id,
@@ -696,9 +696,9 @@ def setup(db):
 
     sql = """
-        DROP VIEW IF EXISTS wv_hive_votes_accounts_permlinks
+        DROP VIEW IF EXISTS hive_votes_accounts_permlinks_view
         ;